@@ -4,7 +4,8 @@ import matplotlib.pyplot as plt
 
 
 def plot_folium(self, m: folium.Map, colormap: str = 'viridis',
-                opacity: float = 0.6, vmax: float = None, vmin: float = None):
+                opacity: float = 0.6, vmax: float = None, vmin: float = None,
+                x=None, y=None):
     """
 
     :param self:
@@ -22,8 +23,10 @@ def plot_folium(self, m: folium.Map, colormap: str = 'viridis',
 
     values = np.flipud(self.values[:].astype(float))
     values = (values - vmin) / (vmax - vmin)
-
-    if 'latitude' in self.dims and 'longitude' in self.dims:
+    if x is not None:
+        latitude = x
+        longitude = y
+    elif 'latitude' in self.dims and 'longitude' in self.dims:
         latitude = self.latitude
         longitude = self.longitude
     elif 'lat' in self.dims:
